﻿Imports Infragistics.Win.DataVisualization
Imports System
Imports System.Collections.Generic
Imports System.ComponentModel
Imports System.Data
Imports System.Drawing
Imports System.Linq
Imports System.Text
Imports System.Threading.Tasks
Imports System.Windows.Forms

Namespace WDC_HighlightMarkers
	Partial Public Class Form1
		Inherits Form

		Private Const HIGHLIGHT_VALUE As Integer = 1
		Private Const NORMAL_VALUE As Integer = 0

		Private Const MARKER_SIZE As Integer = 40

		Private ReadOnly normalMarkerColor As Color = Color.Blue
		Private ReadOnly highlightedMarkerColor As Color = Color.Red

		Public Sub New()
			InitializeComponent()
		End Sub

		Private Sub Form1_Load(ByVal sender As Object, ByVal e As EventArgs) Handles Me.Load
			Dim series As New ScatterLineSeries()
			Dim markers As New BubbleSeries()
			Dim scatterTable As DataTable = CreateScatterTable()

			Dim xAxis As New NumericXAxis()
			Dim yAxis As New NumericYAxis()

			series.DataSource = scatterTable
			series.XAxis = xAxis
			series.YAxis = yAxis
			series.XMemberPath = "ValuesX"
			series.YMemberPath = "ValuesY"

			markers.DataSource = scatterTable
			markers.XAxis = xAxis
			markers.YAxis = yAxis
			markers.XMemberPath = "ValuesX"
			markers.YMemberPath = "ValuesY"
			markers.RadiusMemberPath = "Radius"
			markers.FillMemberPath = "Fill"
			markers.MarkerType = MarkerType.Circle
			markers.Name = "Markers"

'INSTANT VB NOTE: The variable scale was renamed since Visual Basic does not handle local variables named the same as class members well:
			Dim scale_Renamed = New ValueBrushScale()
			scale_Renamed.Brushes.Add(New SolidBrush(normalMarkerColor))
			scale_Renamed.Brushes.Add(New SolidBrush(highlightedMarkerColor))
			scale_Renamed.MinimumValue = 0
			scale_Renamed.MaximumValue = 1
			markers.FillScale = scale_Renamed

			ultraDataChart1.Axes.Add(xAxis)
			ultraDataChart1.Axes.Add(yAxis)

			ultraDataChart1.Series.Add(series)
			ultraDataChart1.Series.Add(markers)
		End Sub

		Private Function CreateScatterTable() As DataTable
			Dim dt As New DataTable()

			dt.Columns.Add("Labels", GetType(String))
			dt.Columns.Add("ValuesX", GetType(Integer))
			dt.Columns.Add("ValuesY", GetType(Integer))
			dt.Columns.Add("Radius", GetType(Integer))
			dt.Columns.Add("Fill", GetType(Integer))

			dt.Rows.Add(New Object() { "January", 200, 150, MARKER_SIZE, NORMAL_VALUE })
			dt.Rows.Add(New Object() { "February", 280, 180, MARKER_SIZE, NORMAL_VALUE })
			dt.Rows.Add(New Object() { "March", 160, 200, MARKER_SIZE, NORMAL_VALUE })
			dt.Rows.Add(New Object() { "April", 120, 123, MARKER_SIZE, NORMAL_VALUE })
			dt.Rows.Add(New Object() { "May", 142, 150, MARKER_SIZE, NORMAL_VALUE })
			dt.Rows.Add(New Object() { "June", 180, 180, MARKER_SIZE, NORMAL_VALUE })
			dt.Rows.Add(New Object() { "July", 198, 123, MARKER_SIZE, NORMAL_VALUE })
			dt.Rows.Add(New Object() { "August", 220, 125, MARKER_SIZE, NORMAL_VALUE })
			dt.Rows.Add(New Object() { "September", 245, 124, MARKER_SIZE, NORMAL_VALUE })
			dt.Rows.Add(New Object() { "October", 208, 182, MARKER_SIZE, NORMAL_VALUE })
			dt.Rows.Add(New Object() { "November", 180, 142, MARKER_SIZE, NORMAL_VALUE })
			dt.Rows.Add(New Object() { "December", 202, 240, MARKER_SIZE, NORMAL_VALUE })

			Return dt
		End Function

		Private Sub ultraDataChart1_SeriesMouseEnter(ByVal sender As Object, ByVal e As ChartMouseEventArgs) Handles ultraDataChart1.SeriesMouseEnter
			If e.Series.Name = "Markers" Then
				Dim item = TryCast(e.Item, DataRowView)

				If item Is Nothing Then
					Return
				End If

				item.Row.SetField(Of Integer)("Fill", HIGHLIGHT_VALUE)
			End If
		End Sub

		Private Sub ultraDataChart1_SeriesMouseLeave(ByVal sender As Object, ByVal e As ChartMouseEventArgs) Handles ultraDataChart1.SeriesMouseLeave
			If e.Series.Name = "Markers" Then
				Dim item = TryCast(e.Item, DataRowView)

				If item Is Nothing Then
					Return
				End If

				item.Row.SetField(Of Integer)("Fill", NORMAL_VALUE)
			End If
		End Sub
	End Class
End Namespace
